.. lyse documentation master file, created by
   sphinx-quickstart on Thu Jun 18 17:05:42 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

lyse
====

**lyse** is a component of the labscript suite. It is a combination API and GUI interface that leverages the API to run user provided analysis scripts of experiment shots. This documentation provides a brief outline of the use of lyse.

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: DOCUMENTATION

   introduction
   examples
   api/index

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: FURTHER DOCUMENTATION

   components

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: LINKS

   Home Page <http://labscriptsuite.org>
   Source Code <https://github.com/labscript-suite/lyse>
   PyPI <https://pypi.org/project/lyse/>
   Anaconda Cloud <https://anaconda.org/labscript-suite/lyse>
   BitBucket Archive <http://bitbucket-archive.labscriptsuite.org/#!/labscript_suite/lyse>

.. todolist::
